

models.Property
===============

.. autoclass:: pykechain.models.Property
   :members:

pykechain Property Types
------------------------

.. autoclass:: pykechain.models.AttachmentProperty
   :members:

.. autoclass:: pykechain.models.SelectListProperty
   :members:

.. autoclass:: pykechain.models.DatetimeProperty
   :members:

pykechain References Property Types
-----------------------------------

.. autoclass:: pykechain.models.MultiReferenceProperty
   :members:
.. autoclass:: pykechain.models.ActivityReferencesProperty
   :members:
.. autoclass:: pykechain.models.ScopeReferencesProperty
   :members:
.. autoclass:: pykechain.models.UserReferencesProperty
   :members:
.. autoclass:: pykechain.models.FormReferencesProperty
   :members:
.. autoclass:: pykechain.models.ContextReferencesProperty
   :members:
.. autoclass:: pykechain.models.StatusReferencesProperty
   :members:
